@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004, 2005 Free Software Foundation
+ * Copyright (C) 2004, 2005, 2008 Free Software Foundation
  *
  * Author: Simon Josefsson
  *
@@ -7,7 +7,7 @@
  *
  * GNUTLS is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * GNUTLS is distributed in the hope that it will be useful, but
@@ -36,6 +36,9 @@ doit (void)
   MD5_CTX c;
   unsigned char md[MD5_DIGEST_LENGTH];
 
+  if (gnutls_global_init() != 0)
+    fail ("gnutls_global_init\n");
+
   if (!gnutls_check_version (LIBGNUTLS_VERSION))
     success ("gnutls_check_version ERROR\n");
 
